<?php
/**
 * Product: Prosodia VGW OS
 * URL: http://prosodia.de/
 * Author: Ronny Harbich
 * Copyright: Ronny Harbich
 * License: GPLv2 or later
 */




class WPVGW_LongTask {

	

	private $taskId;
	

	private $iterationsPerStep;
	

	private $runFunction;
	

	private $endFunction;
	

	private $statusTextTemplate;
	

	private $autoRun = false;

	

	private static $maxExecutionTime = null;


	

	public function isAutoRun() {
		return $this->autoRun;
	}

	

	public function setAutoRun( $auto_run ) {
		$this->autoRun = $auto_run;
	}

	

	public static function setMaxExecutionTime( $max_execution_time ) {
		self::$maxExecutionTime = $max_execution_time;
	}

	

	public function __construct( $task_id, $iterations_per_step, $status_text_template, $run_function, $end_function ) {
		$this->taskId = $task_id;
		$this->iterationsPerStep = $iterations_per_step;
		$this->statusTextTemplate = $status_text_template;
		$this->runFunction = $run_function;
		$this->endFunction = $end_function;

		add_action( 'wp_ajax_' . WPVGW . '_task_' . $this->taskId, array( $this, 'ajax_run' ) );
	}


	

	public function ajax_run() {
		
		
		@ini_set( 'max_execution_time', WPVGW_LongTask::$maxExecutionTime );

		
		$stats = isset( $_POST['wpvgw_task_stats'] ) ? $_POST['wpvgw_task_stats'] : null;
		
		$offset = isset( $_POST['wpvgw_task_offset'] ) ? $_POST['wpvgw_task_offset'] : null;

		if ( $stats == '' )
			$stats = null;
		else {
			
			$stats = unserialize( stripslashes( $stats ) );

			
			if ( $stats === false )
				wp_send_json( $this->create_result( false, null, 0, '', array( array( __( 'Status-Objekt konnte nicht deserialisiert werden.', WPVGW_TEXT_DOMAIN ), WPVGW_ErrorType::Error ) ) ) );
		}

		
		if ( $offset === null || !is_numeric( $offset ) || intval( $offset ) <= -1 )
			wp_send_json( $this->create_result( false, null, 0, '', array( array( __( 'Das Offset hat einen ungültigen Wert.', WPVGW_TEXT_DOMAIN ), WPVGW_ErrorType::Error ) ) ) );

		
		$offset = intval( $offset );


		$hasMoreSteps = true;
		$messages = array();
		$error_messages = null;

		try {
			
			for ( $i = 1; $i <= $this->iterationsPerStep; $i++ ) {
				
				$numberOfIterations = call_user_func_array( $this->runFunction, array( $offset, &$stats, &$error_messages ) );

				
				$offset += $numberOfIterations;

				
				if ( $error_messages !== null && is_array( $error_messages ) ) {
					$hasMoreSteps = false;
					$messages = $error_messages;
					break;
				}

				
				if ( $numberOfIterations === 0 ) {
					$hasMoreSteps = false;
					$messages = call_user_func_array( $this->endFunction, array( $stats ) );
					break;
				}
			}
		} catch ( Exception $e ) {
			if ( WPVGW_Helper::show_debug_info() )
				wp_send_json( $this->create_result( false, null, 0, '', array( array( sprintf( __( 'Es ist ein interner Fehler aufgetreten: %s', WPVGW_TEXT_DOMAIN ), $e->getMessage() ), WPVGW_ErrorType::Error ) ) ) );
			else
				wp_send_json( $this->create_result( false, null, 0, '', array( array( __( 'Es ist ein interner Fehler aufgetreten. Fehlerdetails dürfen nur im Debug-Modus angezeigt werden. Bitte kontaktieren Sie ihren Administrator oder die VG-WORT-Plugin-Entwickler.', WPVGW_TEXT_DOMAIN ), WPVGW_ErrorType::Error ) ) ) );
		}

		
		wp_send_json( WPVGW_LongTask::create_result(
			$hasMoreSteps,
			$stats,
			$offset,
			sprintf( $this->statusTextTemplate, number_format_i18n( $offset ) ),
			$messages
		)
		);
	}

	

	private static function create_result( $has_more_steps, $stats, $offset, $status_text, $messages = array() ) {
		return array(
			'has_more_steps' => $has_more_steps,
			'stats'          => serialize( $stats ),
			'offset'         => $offset,
			'status_text'    => $status_text,
			'messages'       => $messages,
		);
	}

	

	public static function get_javascript() {
		return array(
			'file'         => 'views/admin/task-window.js',
			'slug'         => 'admin-view-task-window',
			'dependencies' => array( 'jquery' ),
			'localize'     => array(
				'object_name' => 'ajax_object',
				'data'        => array(
					'ajax_url'          => admin_url( 'admin-ajax.php' ),
					'start_message'     => __( 'Vorgang wird gestartet …', WPVGW_TEXT_DOMAIN ),
					'aborting_message'  => __( 'Vorgang wird abgebrochen …', WPVGW_TEXT_DOMAIN ),
					'button_close_text' => __( 'Schließen', WPVGW_TEXT_DOMAIN ),
					'button_abort_text' => __( 'Abbrechen', WPVGW_TEXT_DOMAIN ),
				)
			)
		);
	}

	

	public static function render_task_window_html() {
		?>
		<div id="wpvgw-task-window-background">
			<div id="wpvgw-task-window">
				<div id="wpvgw-task-window-spinner" class="spinner"></div>
				<div id="wpvgw-task-window-title"><?php _e( 'Aufwendige Aufgabe', WPVGW_TEXT_DOMAIN ) ?></div>
				<div id="wpvgw-task-window-content"></div>
				<div id="wpvgw-task-window-button"></div>
			</div>
		</div>
		<?php
	}

	

	public function render_auto_run_js() {
		?>
		<script type="text/javascript">
		//<![CDATA[
		jQuery(document).ready(function () {
			wpvgw_task_window.init(function () {
				wpvgw_task_window.run_task('<?php echo( $this->taskId ) ?>');
			});
		});
		//]]>
		</script>
		<?php
	}

}

